@@ -9,5 +9,5 @@
 
 from shift_detector_connector.shift_analyze_result import ShiftAnalyzeResult
 from shift_detector_connector.shift_detector_connector import ShiftDetectorConnector
-from detector_connector import DetectorHttpConnector as ShiftDetectorHttpConnector
+from shift_detector_connector.shift_detector_http_connector import ShiftDetectorHttpConnector
 from shift_detector_connector.shift_detector_kafka_connector import ShiftDetectorKafkaConnector
