@@ -9,7 +9,8 @@
 
 from detector_connector import DetectorConnector
 
-from .shift_analyze_result import ShiftAnalyzeResult
+from shift_detector_connector.shift_analyze_result import ShiftAnalyzeResult
+from shift_detector_connector.shift_settings import ShiftSettings
 
 
 class ShiftDetectorConnector(DetectorConnector):
@@ -17,4 +18,7 @@ class ShiftDetectorConnector(DetectorConnector):
     Config = DetectorConnector.Config
 
     def __init__(self, config: Config, context: Context):
-        super().__init__(config=config, context=context, detector_analyze_result_type=ShiftAnalyzeResult)
+        super().__init__(config=config,
+                         context=context,
+                         detector_analyze_result_type=ShiftAnalyzeResult,
+                         detector_settings_type=ShiftSettings)
